/* screen - environment-specific terminal functions
 * Idris version for ANSI terminal
 */
#include "local.h"
#include "screen.h"
#define get_7bit_char() (getchar() & 0177)	/* "raw" getchar never EOF */
short scr_mode = SCR_TTY;	/* screen mode - TTY or RAW */
short scr_lines = 24;	/* screen lines (default) */
short scr_cols = 80;	/* screen columns (default) */
/* scr_getkey - get a (coded) keyboard char */
SCR_CMDCHAR scr_getkey()
	{
	char c1, c2, c3;
	
	if ((c1 = get_7bit_char()) != '\33')
		return (c1);
	else if ((c2 = get_7bit_char()) == 'O')
		{
		if ((c3 = get_7bit_char()) == 'S')
			return (SCR_EXIT);
		return (getkey());
		}
	else if (c2 == '[')
		{
		switch (c3 = get_7bit_char())
			{
		case 'A':	return (SCR_UP);	/* no "break" needed - all returns */
		case 'B':	return (SCR_DOWN);
		case 'C':	return (SCR_RIGHT);
		case 'D':	return (SCR_LEFT);
		case 'H':	return (SCR_HOME);
		default:	return (scr_getkey());
			}
		}
	else
		return (scr_getkey());
	}
/* remark - print error message, appropriate for scr_mode */
void remark(s1, s2)
	char s1[], s2[];	/* strings to be printed */
	{
	if (scr_mode == SCR_TTY)
		fprintf(stderr, "%s %s\n", s1, s2);
	else
		{
		scr_curs(scr_lines-1, 0);
		scr_print("%s %s; hit any key to continue", s1, s2);
		scr_getkey();
		/* clear message from screen after response */
		/* print 79 spaces, 80 would cause CR on last line
		**     screen would scroll up (on most terminals  
		*/
		scr_curs(scr_lines-1, 0);
		scr_print("                                                    ");
		scr_print("                           ");
		}
	}
/* (new page)
.PE
.PS
 */
/* scr_open - initialize the terminal
 */
void scr_open()
	{
	system("stty +raw -echo");	/* slow but universal */
	printf("\33[>6h");			/* enter keypad-shifted mode */
	scr_mode = SCR_RAW;
	}
/* scr_close - re-establish normal terminal environment
 */
void scr_close()
	{
	printf("\33[>6l");			/* exit keypad-shifted mode */
	system("stty -raw +echo");	/* slow but universal */
	scr_mode = SCR_TTY;
	}
